#coding:utf-8
import os
import smbus
import Adafruit_BMP.BMP085 as bmp
#-------------------------------------------------------------------------------
# Эти классы-обертки пока не предназначены для реальной работы. Хотя могут.
# Они предназначены для экспериментов в процессе разработки концепта. 
# Просто в них нет ни защит, ни проверок, ни обработки исключений. Ничего, кроме
# голой схемы. Но на свой страх и риск - с ними вполне можно работать...
# 
# OldBean 17.01.11
#-------------------------------------------------------------------------------
class DS18B20: # Класс датчика температуры DS18B20
  path = "/sys/bus/w1/devices"
  def __init__(self, id):
    self.id = id
    self.fn = DS18B20.path + ("/28-%012x/w1_slave" % (id))
  def ReadRaw(self): # Чтение "сырых" данных датчика температуры (из файла fn)
    f = open(self.fn, 'r')
    lines = f.readlines()
    f.close()
    return lines
  def ReadT(self): # Получение значения температуры 
    lines = self.ReadRaw()
    while lines[0].strip()[-3:] != 'YES': # Пока преобразование не закончено
      lines = self.ReadRaw()
    pos = lines[1].find('t=') # Значение температуры после 't='
    if pos != -1:
      return float(lines[1][pos + 2:])/1000
    return -1
  def IDs(): # Это - метод класса. Он возвращает список ID всех подключенных датчиков
    fnl = os.listdir(DS18B20.path)
    idl = []
    for fn in fnl:
      if fn[:3] == "28-":
        idl.append(int(fn[-12:], 16))
    return idl
  IDs = staticmethod(IDs)
  T = property(ReadT)
#-------------------------------------------------------------------------------
class BMP180: # Класс датчика атмосферного давления BMP180
  def __init__(self):
    self.sensor = bmp.BMP085()
  def ReadP(self):
    return self.sensor.read_pressure()/133.322 # Паскали -> в мм.рт.ст.
  def ReadT(self):
    return self.sensor.read_temperature()
  P = property(ReadP)
  T = property(ReadT)
#-------------------------------------------------------------------------------
class RMS: # Класс датчика среднеквадратичного напряжения сети
  def __init__(self, addr, bus = smbus.SMBus(1)):
    self.addr = addr
    self.bus = bus
  def ReadV(self):
    return self.bus.read_byte(self.addr) + 100
  V = property(ReadV)
#-------------------------------------------------------------------------------
if __name__ == "__main__": # Тестирование классов модуля sens
  # Тестирование всех датчиков DS18B20 на шине 1-wire
  print "\nДатчики DS18B20"
  tsIDs = DS18B20.IDs() # Список ID всех датчиков DS18B20 на шине 1-wire
  if len(tsIDs) == 0:
    print "Датчики отсутствуют"
  else:
    for id in tsIDs:
      ts = DS18B20(id) # Создаем объект (датчик DS18B20)
      temperature = ts.T # Измеряем температуру этим датчиком
      print "0x%012x :% 7.3f°C" % (id, temperature)
  # Тестирование датчика BMP180
  print "\nДатчик BMP180"
  try:
    bmp = BMP180()
    print "Давление: \t%5.1f мм.рт.ст." % (bmp.P)
    print "Температура:\t%5.2f°C" % (bmp.T)
  except:
    print "Датчик отсутстует или неисправен"
  # Тестирование датчика RMS на шине I2C
  print "\nДатчик RMS"
  try:
    vs = RMS(0x05) # Создаем объект - датчик RMS
    print "Среднеквадратичное напряжение: %d V" % (vs.V) # Измеряем и выводим напругу
  except:
    print "Датчик отсутстует или неисправен"
